pub struct GetSessionTeeStatusResponse {
pub stream: i32,
pub missed_bytes: u64,
pub disconnected: bool,
}Fields
stream: i32missed_bytes: u64disconnected: boolImplementations
Sourceimpl GetSessionTeeStatusResponse
impl GetSessionTeeStatusResponse
Sourcepub fn stream(&self) -> TeeStreamKind
pub fn stream(&self) -> TeeStreamKind
Returns the enum value of stream, or the default if the field is set to an invalid enum value.
Sourcepub fn set_stream(&mut self, value: TeeStreamKind)
pub fn set_stream(&mut self, value: TeeStreamKind)
Sets stream to the provided enum value.