pub struct RegisterSessionObserverRequest {
pub session_id: String,
pub session_kind: i32,
pub categories: Vec<u32>,
pub ring_capacity_events: u32,
pub backpressure: i32,
}Fields
session_id: Stringsession_kind: i32categories: Vec<u32>Requested categories. Each value is an ObserverEventCategory integer (stored as repeated uint32 to match the Phase 1 in-process config which accepts an arbitrary set). Empty = lifecycle only.
ring_capacity_events: u320 means use the daemon default (1024).
backpressure: i32Implementations
Sourceimpl RegisterSessionObserverRequest
impl RegisterSessionObserverRequest
Sourcepub fn session_kind(&self) -> ObserverSessionKind
pub fn session_kind(&self) -> ObserverSessionKind
Returns the enum value of session_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_session_kind(&mut self, value: ObserverSessionKind)
pub fn set_session_kind(&mut self, value: ObserverSessionKind)
Sets session_kind to the provided enum value.
Sourcepub fn backpressure(&self) -> ObserverBackpressure
pub fn backpressure(&self) -> ObserverBackpressure
Returns the enum value of backpressure, or the default if the field is set to an invalid enum value.
Sourcepub fn set_backpressure(&mut self, value: ObserverBackpressure)
pub fn set_backpressure(&mut self, value: ObserverBackpressure)
Sets backpressure to the provided enum value.