#[repr(i32)]pub enum ErrorCode {
Unspecified = 0,
ErrorVersionUnsupported = 1,
ErrorServiceUnknown = 2,
ErrorBackendSpawnFailed = 3,
ErrorRateLimited = 4,
ErrorShuttingDown = 5,
ErrorPeerRejected = 6,
ErrorInternal = 7,
ErrorVersionBlocked = 8,
ErrorFdPressure = 9,
}Variants
Unspecified = 0
ErrorVersionUnsupported = 1
ErrorServiceUnknown = 2
ErrorBackendSpawnFailed = 3
ErrorRateLimited = 4
ErrorShuttingDown = 5
ErrorPeerRejected = 6
ErrorInternal = 7
ErrorVersionBlocked = 8
version below min-supported floor
ErrorFdPressure = 9
reserved for v1.x SELF_DEMOTE
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.